Enum MmError
Source pub enum MmError {
OutOfMemory,
MisalignedAddress,
Overlap,
NotFound,
}
An enum which describes possible memory management errors that can occur
No free memory left to allocate
The given address is not frame aligned
The requested region overlaps with an existing one
No region at the given address found
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.